@@ -5,11 +5,13 @@ Created on 2021-08-19
 """
 
 import getpass
-from unittest import TestCase
 import os
+import unittest
+
 from ngwidgets.profiler import Profiler
 
-class Basetest(TestCase):
+
+class Basetest(unittest.TestCase):
     """
     base test case
     """
@@ -18,14 +20,14 @@ class Basetest(TestCase):
         """
         setUp test environment
         """
-        TestCase.setUp(self)
+        unittest.TestCase.setUp(self)
         self.debug = debug
         self.profile = profile
         msg = f"test {self._testMethodName}, debug={self.debug}"
         self.profiler = Profiler(msg, profile=self.profile)
 
     def tearDown(self):
-        TestCase.tearDown(self)
+        unittest.TestCase.tearDown(self)
         self.profiler.time()
 
     @staticmethod
@@ -41,3 +43,7 @@ class Basetest(TestCase):
     def isUser(name: str):
         """Checks if the system has the given name"""
         return getpass.getuser() == name
+
+
+if __name__ == "__main__":
+    unittest.main()
