@@ -3,13 +3,16 @@ Created on 2023-09-12
 
 @author: wf
 """
-import os
+
 import logging
-from ngwidgets.webserver import NiceGuiWebserver, WebserverConfig
+import os
+
+from nicegui import Client, ui
+
 from ngwidgets.local_filepicker import LocalFilePicker
-from ngwidgets.widgets import About
-from nicegui import ui, Client
 from ngwidgets.log_view import LogElementHandler
+from ngwidgets.webserver import NiceGuiWebserver, WebserverConfig, WebSolution
+from ngwidgets.widgets import About
 
 
 class InputWebserver(NiceGuiWebserver):
@@ -22,21 +25,56 @@ class InputWebserver(NiceGuiWebserver):
         constructor
         """
         NiceGuiWebserver.__init__(self, config=config)
-        self.is_local = False
-        self.input = ""
         self.logger = logging.getLogger()
 
         @ui.page("/")
-        async def home(client: Client):
-            return await self.home(client)
+        async def home_page(client: Client):
+            return await self.page(client, InputWebSolution.home)
 
         @ui.page("/settings")
-        async def settings():
-            return await self.settings()
+        async def settings_page(client: Client):
+            return await self.page(client, InputWebSolution.settings)
 
         @ui.page("/about")
-        async def about():
-            return await self.about()
+        async def about_page(client: Client):
+            return await self.page(client, InputWebSolution.about)
+
+    def configure_run(self):
+        """
+        override the run configuration
+        """
+        NiceGuiWebserver.configure_run(self)
+        args = self.args
+        self.is_local = args.local
+        if hasattr(args, "root_path"):
+            self.root_path = os.path.abspath(args.root_path)
+        else:
+            self.root_path = None
+
+
+class InputWebSolution(WebSolution):
+    """
+    A WebSolution that is focused on handling a single input.
+
+    Attributes:
+        is_local (bool): Indicates if the input source is local or remote.
+        input (str): The input data or path to be processed.
+    """
+
+    def __init__(self, webserver: NiceGuiWebserver, client: Client):
+        """
+        Initializes the InputWebSolution instance with the webserver and client.
+
+        Args:
+            webserver (NiceGuiWebserver): The webserver instance this solution is part of.
+            client (Client): The client interacting with this solution.
+        """
+        super().__init__(webserver, client)
+        self.debug = webserver.debug
+        self.root_path = None
+        self.is_local = False
+        self.input = ""
+        self.render_on_load = False
 
     def input_changed(self, cargs):
         """
@@ -69,7 +107,7 @@ class InputWebserver(NiceGuiWebserver):
         """
         self.input_input.set_value(input_str)
         self.read_input(input_str)
-        if with_render:
+        if with_render or self.args.render_on_load:
             await self.render(None)
 
     async def reload_file(self):
@@ -106,7 +144,7 @@ class InputWebserver(NiceGuiWebserver):
 
     pass
 
-    async def home(self, _client: Client):
+    async def home(self):
         """
         provide the main content page
 
@@ -118,10 +156,13 @@ class InputWebserver(NiceGuiWebserver):
         show about
         """
         await self.setup_content_div(self.setup_about)
-        
+
     def setup_about(self):
+        """
+        display an About
+        """
         self.about_div = About(self.config.version)
- 
+
     async def setup_footer(
         self,
         with_log: bool = True,
@@ -135,8 +176,8 @@ class InputWebserver(NiceGuiWebserver):
         if with_log:
             self.log_view = ui.log(max_lines=max_lines).classes(log_classes)
             if handle_logging:
-                self.log_view_handler = LogElementHandler(self.log_view)
-                self.logger.addHandler(self.log_view_handler)
+                self.log_view_handler = LogElementHandler(self,self.log_view)
+                self.webserver.logger.addHandler(self.log_view_handler)
         else:
             self.log_view = None
         await super().setup_footer()
@@ -151,44 +192,44 @@ class InputWebserver(NiceGuiWebserver):
         """
         Generates the settings page
         """
-        self.setup_menu()
-        ui.checkbox("debug", value=self.debug).bind_value(self, "debug")
-        ui.checkbox("debug with trace", value=True).bind_value(self, "do_trace")
-        ui.checkbox("render on load", value=self.render_on_load).bind_value(
-            self, "render_on_load"
-        )
-        self.configure_settings()
-        await self.setup_footer()
+
+        def show():
+            with ui.row():
+                ui.checkbox("debug", value=self.webserver.debug).bind_value(
+                    self.webserver, "debug"
+                )
+                ui.checkbox(
+                    "debug with trace", value=self.webserver.do_trace
+                ).bind_value(self.webserver, "do_trace")
+                ui.checkbox("render on load", value=self.render_on_load).bind_value(
+                    self, "render_on_load"
+                )
+            self.configure_settings()
+
+        await self.setup_content_div(show)
 
     def configure_settings(self):
         """
-        overrideable settings configuration
+        Configures settings specific to this web solution.
+        This method is intended to be overridden by subclasses to provide custom settings behavior.
+        The base method does nothing and can be extended in subclasses.
         """
-        pass
 
     def configure_menu(self):
         """
-        overrideable menu configuration
-        """
-
-    def configure_run(self):
-        """
-        overrideable configuration
+        Configures the menu items specific to this web solution.
+        This method is intended to be overridden by subclasses to provide custom menu behavior.
+        The base method does nothing and can be extended in subclasses.
         """
         pass
 
-    def run(self, args):
+    def prepare_ui(self):
         """
-        Runs the UI of the web server.
-
-        Args:
-            args (list): The command line arguments.
+        handle the command line arguments
         """
+        WebSolution.prepare_ui(self)
+        args = self.webserver.args
         self.input = args.input
+        self.root_path = self.webserver.root_path
         self.is_local = args.local
-        if hasattr(args, "root_path"):
-            self.root_path = os.path.abspath(args.root_path)
-        else:
-            self.root_path = None
         self.render_on_load = args.render_on_load
-        super().run(args)
